@@ -75,7 +75,9 @@ class BytesWriter():
 
     def writeStr(self, value: str):
         valueBytes = value.encode("utf8")
-        self._write(f"{len(valueBytes)+1}p", valueBytes)
+        self._write("H", len(value)) # 0 ~ 65535
+        self._write(f"{len(valueBytes)}s", valueBytes)
+        # self._write(f"{len(valueBytes)+1}p", valueBytes) # 一些小语种在C#解析会出问题，例如俄语，印地语，但是没有找到绝对的规律
         return self
 
     # -----
