@@ -1,6 +1,6 @@
 import gzip
 from http.cookiejar import CookieJar
-from typing import Any, Optional
+from typing import Any
 from urllib.parse import urlencode
 from urllib.request import (HTTPCookieProcessor, Request, build_opener,
                             install_opener, urlopen)
@@ -21,7 +21,7 @@ _opener = build_opener(_cookieProc)
 install_opener(_opener)
 
 
-def getHeaderByDefault(headers: Optional[dict[str, str]]):
+def getHeaderByDefault(headers: dict[str, str] | None):
     result = dict(_defaultHeader)
     if headers:
         for key, value in headers.items():
@@ -29,7 +29,7 @@ def getHeaderByDefault(headers: Optional[dict[str, str]]):
     return result
 
 
-def httpGet(url: str, headers: Optional[dict[str, str]] = None, timeout: int = 30, retry: int = 3):
+def httpGet(url: str, headers: dict[str, str] | None = None, timeout: int = 30, retry: int = 3):
     method = 'GET'
     if headers:
         headers = getHeaderByDefault(headers)
